@@ -117,7 +117,7 @@ validate (GisAccountPageLocal *page)
   GtkWidget *entry;
   const gchar *name, *username;
   gboolean parental_controls_enabled;
-  gchar *tip;
+  g_autofree gchar *tip = NULL;
 
   g_clear_handle_id (&page->timeout_id, g_source_remove);
 
@@ -139,8 +139,10 @@ validate (GisAccountPageLocal *page)
   if (page->valid_username)
     set_entry_validation_checkmark (GTK_ENTRY (entry));
 
+  const gchar *current_label = gtk_label_get_text (GTK_LABEL (page->username_explanation));
+  if (!g_str_equal (tip, current_label) && !g_str_equal (current_label, ""))
+    gtk_accessible_announce (GTK_ACCESSIBLE (page), tip, GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_MEDIUM);
   gtk_label_set_text (GTK_LABEL (page->username_explanation), tip);
-  g_free (tip);
 
   validation_changed (page);
 
@@ -201,6 +203,7 @@ username_changed (GtkComboBoxText     *combo,
   if (*username == '\0')
     page->has_custom_username = FALSE;
   else if (gtk_widget_has_focus (entry) ||
+           gtk_widget_get_focus_child (entry) ||
            gtk_combo_box_get_active (GTK_COMBO_BOX (page->username_combo)) > 0)
     page->has_custom_username = TRUE;
 
@@ -577,6 +580,10 @@ gis_account_page_local_init (GisAccountPageLocal *page)
 {
   g_type_ensure (GIS_TYPE_PAGE_HEADER);
   gtk_widget_init_template (GTK_WIDGET (page));
+  g_object_set (G_OBJECT (page),
+              "accessible-role",
+              GTK_ACCESSIBLE_ROLE_GROUP,
+              NULL);
 }
 
 gboolean
